@@ -1,9 +1,6 @@
 
 package PRANG::Graph::Choice;
-{
-  $PRANG::Graph::Choice::VERSION = '0.17';
-}
-
+$PRANG::Graph::Choice::VERSION = '0.18';
 use 5.010;
 use Moose;
 use MooseX::Params::Validate;
@@ -257,7 +254,7 @@ sub output {
 	else {
 
 		# textnode ... jfdi
-		my $tn = $node->ownerDocument->createTextNode($value);
+		my $tn = $self->createTextNode($node->ownerDocument, $value);
 		$node->appendChild($tn);
 	}
 }
