@@ -1,9 +1,6 @@
 
 package PRANG::Graph::Element;
-{
-  $PRANG::Graph::Element::VERSION = '0.17';
-}
-
+$PRANG::Graph::Element::VERSION = '0.18';
 use 5.010;
 use Moose;
 use MooseX::Params::Validate;
@@ -391,12 +388,12 @@ sub output  {
 			}
 		}
 		elsif ( $self->has_contents and defined $value ) {
-			my $tn = $doc->createTextNode($value);
+		    my $tn = $self->createTextNode($doc, $value);
 			$nn->appendChild($tn);
 		}
 	}
 	else {
-		$nn = $doc->createTextNode($value);
+	    $nn = $self->createTextNode($doc, $value);
 		$node->appendChild($nn);
 	}
 }
