@@ -1,9 +1,6 @@
 
 package PRANG::Graph::Meta::Element;
-{
-  $PRANG::Graph::Meta::Element::VERSION = '0.17';
-}
-
+$PRANG::Graph::Meta::Element::VERSION = '0.18';
 use Moose::Role;
 use PRANG::Util qw(types_of);
 use MooseX::Params::Validate;
@@ -105,7 +102,7 @@ sub error {
     my ( $message ) = pos_validated_list(
         \@_,
         { isa => 'Str' },
-    );
+    );      
     
 	confess $self->_error($message);
 }
@@ -278,10 +275,6 @@ sub build_graph_node {
 						"$nodeName_r_prefix->{$xmlns}:$plugin_nodeName";
 				}
 				if ( exists $nodeName->{$plugin_nodeName} ) {
-				    use Data::Dumper;
-				    warn Dumper $nodeName;
-				    warn $plugin_nodeName;
-				    warn $user;
 					$self->error(
 "Both '$user' and '$nodeName->{$plugin_nodeName}' plug-in type specify nodename $plugin_nodeName"
 							.(
@@ -630,10 +623,7 @@ sub build_graph_node {
 }
 
 package Moose::Meta::Attribute::Custom::Trait::PRANG::Element;
-{
-  $Moose::Meta::Attribute::Custom::Trait::PRANG::Element::VERSION = '0.17';
-}
-
+$Moose::Meta::Attribute::Custom::Trait::PRANG::Element::VERSION = '0.18';
 sub register_implementation {
 	"PRANG::Graph::Meta::Element";
 }
