@@ -1,9 +1,6 @@
 
 package PRANG::Graph::Text;
-{
-  $PRANG::Graph::Text::VERSION = '0.17';
-}
-
+$PRANG::Graph::Text::VERSION = '0.18';
 use Moose;
 use MooseX::Params::Validate;
 use XML::LibXML;
@@ -107,7 +104,8 @@ sub output  {
 	}
 	return unless length($value//"");
 	my $doc = $node->ownerDocument;
-	my $tn = $doc->createTextNode($value);
+	my $tn = $self->createTextNode($doc, $value);
+		
 	$node->appendChild($tn);
 }
 
