@@ -1,8 +1,8 @@
 
 package PRANG::Util;
-{
-  $PRANG::Util::VERSION = '0.17';
-}
+$PRANG::Util::VERSION = '0.18';
+use strict;
+use warnings;
 
 use Sub::Exporter -setup =>
 	{ exports => [qw(types_of)] };
