@@ -1,10 +1,8 @@
 
 package PRANG::XMLSchema::Types;
-{
-  $PRANG::XMLSchema::Types::VERSION = '0.17';
-}
-
+$PRANG::XMLSchema::Types::VERSION = '0.18';
 use strict;
+use warnings;
 use Moose::Util::TypeConstraints;
 
 subtype "PRANG::XMLSchema::normalizedString"
